@@ -12,9 +12,11 @@ __DATA__
 %= $self->view('Page', title => 'Hello', sub {
     <h1>Hello</h1>
     <%= "<a href='/hello'>Hello</a>" %>
-    %= form_for('person', sub {
+    %= form_for('person', {allow_method_names_outside_object=>1}, sub {
         % my ($self, $fb, $model) = @_;\
-        %= $fb->input('name');
+        <%= $fb->field('name')
+            ->label
+            ->input %>
         %= $fb->input('age');
     % });\
 % });
\ No newline at end of file
